pub trait Upgrade {
type Target: Downgrade;
// Required method
fn upgrade(&self) -> Option<Self::Target>;
}Expand description
Types which can be upgraded from their weak form,
such as std::rc::Weak and std::sync::Weak.
pub trait Upgrade {
type Target: Downgrade;
// Required method
fn upgrade(&self) -> Option<Self::Target>;
}Types which can be upgraded from their weak form,
such as std::rc::Weak and std::sync::Weak.